package details


/**
 * Created by abdulbasit on 25/06/2023.
 */

import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.fillMaxHeight
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.text.selection.SelectionContainer
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.rotate
import androidx.compose.ui.draw.shadow
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.LineHeightStyle
import androidx.compose.ui.text.style.TextOverflow
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import model.Recipe

@Composable
fun InstructionItem(
    recipe: Recipe,
    index: Int,
    count: Int,
    slider: Float) {
    Box(modifier = Modifier.padding(start = 16.dp, end = 16.dp, top = 8.dp)) {
        Box(
            modifier = Modifier
                .fillMaxWidth()
                .padding(top = 8.dp)
                .border(
                    width = 2.dp,
                    color = if (recipe.bgColor != MaterialTheme.colorScheme.primaryContainer) MaterialTheme.colorScheme.secondaryContainer else MaterialTheme.colorScheme.background,
                    shape = RoundedCornerShape(35.dp)
                )
        ) {
            SelectionContainer {
                Text(
                    text = scaleRecipeServingsInstructions(recipe.instructions[index], slider),
                    style = MaterialTheme.typography.bodyLarge.copy(
                        letterSpacing = 1.2.sp,
                    ),
                    modifier = Modifier
                        .fillMaxWidth().fillMaxHeight()
                        .padding(start = 70.dp, end = 20.dp, top = 20.dp, bottom = 20.dp),
                )
            }
        }

        Box(
            modifier = Modifier
        ) {
            Box(
                modifier = Modifier
                    .size(50.dp)
                    .shadow(elevation = 10.dp, shape = CircleShape)
                    .background(
                        if (recipe.bgColor != MaterialTheme.colorScheme.primaryContainer) MaterialTheme.colorScheme.secondaryContainer else MaterialTheme.colorScheme.background,
                        CircleShape
                    ),
                contentAlignment = Alignment.Center
            ) {
                Text(
                    text = "$count",
                    style = MaterialTheme.typography.displayMedium.copy(
                        lineHeightStyle = LineHeightStyle(
                            alignment = LineHeightStyle.Alignment.Center,
                            trim = LineHeightStyle.Trim.None
                        )
                    ),
                    color = if (recipe.bgColor != MaterialTheme.colorScheme.primaryContainer) MaterialTheme.colorScheme.onSecondaryContainer else MaterialTheme.colorScheme.onBackground,
                    fontWeight = FontWeight.W600,
                    modifier = Modifier.padding(5.dp).rotate(-30f),
                    maxLines = 1,
                    overflow = TextOverflow.Ellipsis
                )
            }
        }
    }
}
