package view

import SortBy
import Theme
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.padding
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.MoreVert
import androidx.compose.material3.DropdownMenu
import androidx.compose.material3.DropdownMenuItem
import androidx.compose.material3.HorizontalDivider
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.dp

@Composable
fun MainDropDown(
    isLarge: Boolean,
    andOr: Boolean,
    descending: Boolean,
    theme: Theme,
    sortBy: SortBy,
    onTag: () -> Unit,
    onSortBy: () -> Unit,
    onDesc: () -> Unit,
    onTheme: () -> Unit,
    onRandom: () -> Unit,
    onBack: () -> Unit,
    onClose: () -> Unit,
) {
    var expanded by remember { mutableStateOf(false) }

    Box(
        modifier = Modifier
            .padding(16.dp)
    ) {
        IconButton(onClick = { expanded = !expanded }) {
            Icon(imageVector = Icons.Default.MoreVert, contentDescription = "More Options")
        }
        DropdownMenu(
            expanded = expanded,
            onDismissRequest = { expanded = false }
        ) {
            DropdownMenuItem(
                text = { Text(theme.name) },
                onClick = onTheme
            )

            HorizontalDivider()

            DropdownMenuItem(
                text = { Text("Filter Style: ".plus(if(andOr) "OR" else "AND")) },
                onClick = onTag
            )
            DropdownMenuItem(
                text = { Text(text = "Sort By: ".plus(sortBy.name)) },
                onClick = onSortBy
            )
            DropdownMenuItem(
                text = { Text(text = "Sort Order: ".plus(if(descending)"DESC" else "ASC")) },
                onClick = onDesc
            )

            HorizontalDivider()

            DropdownMenuItem(
                text = { Text("Random Filtered Recipe") },
                onClick = onRandom
            )
            if (isLarge) {

                HorizontalDivider()

                DropdownMenuItem(
                    text = { Text("Go Back") },
                    onClick = onBack
                )

                DropdownMenuItem(
                    text = { Text("Close app") },
                    onClick = onClose
                )
            }
        }
    }
}